Crate porthole

Crate porthole 

Porthole resolves open network ports so you don’t have to.

examples

println!("next available port is {}", porthole::open().unwrap())

Structs

Iter
An iterator over open ports

Functions

iter
produces an Iter instance to iterate over open ports
open
Returns the next available network port on the current host